@@ -546,7 +546,7 @@ GethApiDouble.prototype.evm_increaseTime = function(seconds, callback) {
 };
 
 GethApiDouble.prototype.evm_setTime = function(date, callback) {
-  callback(null, this.state.blockchain.setTime(date));
+  callback(null, this.state.blockchain.setTime(new Date(date)));
 };
 
 GethApiDouble.prototype.evm_mine = function(timestamp, callback) {
